You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ma...@apache.org on 2013/08/19 20:19:06 UTC

svn commit: r1515544 - /openoffice/ooo-site/trunk/content/download/test/download.js

Author: marcus
Date: Mon Aug 19 18:19:06 2013
New Revision: 1515544

URL: http://svn.apache.org/r1515544
Log:
Updated JS code

Modified:
    openoffice/ooo-site/trunk/content/download/test/download.js

Modified: openoffice/ooo-site/trunk/content/download/test/download.js
URL: http://svn.apache.org/viewvc/openoffice/ooo-site/trunk/content/download/test/download.js?rev=1515544&r1=1515543&r2=1515544&view=diff
==============================================================================
--- openoffice/ooo-site/trunk/content/download/test/download.js (original)
+++ openoffice/ooo-site/trunk/content/download/test/download.js Mon Aug 19 18:19:06 2013
@@ -133,6 +133,7 @@ function getLink() {
 	var chk_link = "";
 
 	getLanguage();
+	hasMirrorLink();
 	getPlatform();
 	getFilesize();
 
@@ -224,15 +225,15 @@ function getPlatform() {
 	  if ( os.indexOf( "qnx"		) != -1 )	UI_PLATFORM	= "QNX";
 	  if ( os.indexOf( "x11"		) != -1 )	UI_PLATFORM	= "an unknown OS with X11 support";
 
-	  if ( os.indexOf( "arm"		) != -1 )	UI_PLATFORM	= "ARM mobile/tablet devices";
+	  if ( os.indexOf( "arm"		) != -1 )	UI_PLATFORM	= "ARM mobile devices";
 
 	  if ( ua.indexOf( "ppc"		) != -1 ||
 	       ua.indexOf( "power_pc"		) != -1 )	UI_PLATFORM	= "Mac OS PPC (DMG)";
 	  if ( ua.indexOf( "iphone"		) != -1 ||
 	       ua.indexOf( "ipad"		) != -1 ||
-	       ua.indexOf( "ipod"		) != -1	)	UI_PLATFORM	= "Apple mobile devices (iPhone/iPad/iPod)";
+	       ua.indexOf( "ipod"		) != -1	)	UI_PLATFORM	= "Apple iPhone/iPad/iPod";
 	  if ( ua.indexOf( "android"		) != -1 ||
-	       av.indexOf( "android"		) != -1 )	UI_PLATFORM	= "Android mobile/tablet devices";	
+	       av.indexOf( "android"		) != -1 )	UI_PLATFORM	= "Android mobile devices";	
 	  if ( ua.indexOf( "blackberry"		) != -1 )	UI_PLATFORM	= "Blackberry smartphones";
 	  if ( ua.indexOf( "nokia"		) != -1 )	UI_PLATFORM	= "Nokia mobile devices";
 	  if ( ua.indexOf( "symbian"		) != -1 )	UI_PLATFORM	= "mobile phones with Symbian OS";
@@ -250,7 +251,7 @@ function getPlatform() {
 	  if ( ua.indexOf( "playstation"	) != -1 )	UI_PLATFORM	= "Sony Playstation";
 	  if ( ua.indexOf( "psp"		) != -1 )	UI_PLATFORM	= "Sony Playstation Portable";
 	  if ( ua.indexOf( "nintendo"		) != -1 )	UI_PLATFORM	= "Nintendo game console";
-	  if ( ua.indexOf( "wii"		) != -1 )	UI_PLATFORM	= "Wii game console";
+	  if ( ua.indexOf( "wii"		) != -1 )	UI_PLATFORM	= "Nintendo Wii game console";
 
 	  // If the $UI_PLATFORM variable is already filled, then something was recognized and no more work is need
 	  if ( UI_PLATFORM ) {
@@ -284,8 +285,9 @@ function getPlatform() {
 	      }
 	    }
 	    // 64-bit, DEB or RPM?
-	    if ( os.indexOf( "x86_64"		) != -1 ||
-		 os.indexOf( "x86-64"		) != -1 ||
+	    if ( os.indexOf( "_64"		) != -1 ||
+		 os.indexOf( "-64"		) != -1 ||
+		 os.indexOf( "x64"		) != -1 ||
 		 os.indexOf( "amd64"		) != -1 ) {	UI_PLATFORM	= "Linux 64-bit (RPM)";
 								URL_PLATFORM	= "Linux_x86-64_install-rpm";
 								EXTENSION	= ".tar.gz";
@@ -342,8 +344,8 @@ function getFilesize() {
 			RELEASE_MATRIX_PLATFORM_POS = -1;
 	}
 
-	// If a platform was found, assign the array data and filesize from the release matrix
-	if ( RELEASE_MATRIX_PLATFORM_POS > -1 ) {
+	// If a platform was found and no error occurred, assign the array data and filesize from the release matrix
+	if ( RELEASE_MATRIX_PLATFORM_POS > -1 && !ERROR ) {
 		// Assign all values from the release matrix of language and platform
 		RELEASE_MATRIX_PLATFORM		= release_aoo400_matrix[ LANG_ISO ][ RELEASE_MATRIX_PLATFORM_POS ];